@@ -12,7 +12,7 @@ use strict;
 @ISA = qw(Verilog::Netlist::File::Struct
 	Verilog::Netlist::Subclass);
 
-$VERSION = '3.402';
+$VERSION = '3.404';
 
 structs('new',
 	'Verilog::Netlist::File::Struct'
@@ -438,7 +438,9 @@ sub read {
 				      );
 
     my $keep_cmt = ($params{keep_comments} || $netlist->{keep_comments});
-    my $parser = Verilog::Netlist::File::Parser->new
+    my $parser_class = ($params{parser} || $netlist->{parser});
+
+    my $parser = $parser_class->new
 	( fileref=>$fileref,
 	  filename=>$filepath,	# for ->read
 	  metacomment=>($params{metacomment} || $netlist->{metacomment}),
@@ -533,7 +535,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2013 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2014 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
